@@ -1,7 +1,9 @@
 package Acme'Schrodinger'Do;
-our $VERSION = '0.03';
-sub sdo (&;$$) {for(1..(defined $_[2] ? $_[2] : 1)){$_[0]->() if defined $_[1] ? $_[1] > rand(100) : 1}}
-sub import {*{caller().'::sdo'} = \&sdo}
+our $VERSION = '0.04';
+sub import {
+	my $c = caller();
+	*{$c.'::sdo'} = sub (&;$$) {for(1..(defined $_[2] ? $_[2] : 1)){$_[0]->() if defined $_[1] ? $_[1] > rand(100) : 1}};
+	*{$c.'::doAny'} = sub(&;@){$_[int(rand(100)/(100/scalar(@_)))]->();}}
 1;
 __END__
 =head1 NAME
@@ -13,6 +15,10 @@ Acme::Schrodinger::Do - do block occasionally
   use Acme'Schrodinger'Do;
   sdo {kill $the,$cat} '50%';
   sdo {kill $the,$cat} 50 => 10                       # 10 boxes and cats
+  doAny {kill $cat, $number1}
+    sub {kill $cat, $number2}
+  , sub {kill $cat, $number3}
+  , sub {kill $cat, $number4};                        # do any one block
 
 =head1 DESCRIPTION
 
@@ -31,6 +37,14 @@ sdo BLOCK Probability => Iterate
 	sdo {print 'Just do it!',"\n"};                   # like 'do' block
 	sdo {print 'do it three times!'} 100 => 3;        # do for 1..3
 
+doAny BLOCK(S)
+
+	doAny {'???'}               # (100/1)% doing block
+	doAny {'???'} sub {'???'}   # (100/2)% foreach block
+	doAny {'???'} 
+	  sub {'???'}
+	, sub {'???'};              # (100/3)% for each block
+
 =head1 SEE ALSO
 
 http://en.wikipedia.org/wiki/Schr%C3%B6dinger%27s_cat
